/*
 * @file LcdDisplay.c
 * LCD Display Library
 * @date December 25, 2014
 * @author Michael Burmeister 
 * 
*/

#include "simpletools.h"                      // Include simple tools
#include "LcdDisplay.h"

serial *LcdDsp = NULL;

void Lcd_Open(int Baud, int Rx, int Tx)
{
  LcdDsp = serial_open(Rx, Tx, 0, Baud);
}

void Lcd_PosCursor(int x, int y)
{
  int i = 128;
  
  if (y > 1)
    return;
  y = y * 20;
  i = y + x + i;
  if (LcdDsp != NULL)
    serial_txChar(LcdDsp, i);
  return;
}

void Lcd_PlayNote(int n, int len)
{
  int i = len + 208;
  int j = n + 220;
  if (LcdDsp != NULL)
  {
    serial_txChar(LcdDsp, i);
    serial_txChar(LcdDsp, j);
  }
  return;
}

void Lcd_Clr()
{
  if (LcdDsp != NULL)
    serial_txChar(LcdDsp, 12);
  Lcd_Chg(1, 1, 0);
}

void Lcd_Chg(int O, int C, int B)
{
  int i = 21;
  if (O)
  {
    i++;
    if (C)
      i += 2;
    if (B)
      i++;
  }
  if (LcdDsp != NULL)
    serial_txChar(LcdDsp, i);
}

void Lcd_BackLight(int O)
{
  int i = 18;
  if (O)
    i--;
  if (LcdDsp != NULL)
    serial_txChar(LcdDsp, i);
}

void Lcd_Chrs(char *c)
{
  int i = 0;
  if (LcdDsp == NULL)
    return;
  while (c[i] != 0)
  {
    serial_txChar(LcdDsp, c[i++]);
  }
}

void Lcd_Close()
{
  if (LcdDsp != NULL)
    serial_close(LcdDsp);
  LcdDsp = NULL;
}  