/*
 * @file LcdDisplay.h
 * @author Michael Burmeister
 * @brief This library adds functions for using the Parallax LCD Display
 * These functions convert the byte code data into functions for easy reference
 * 
*/

#ifndef LCDDISPLAY_H
#define LCDDISPLAY_H
 
#include "simpletools.h"                      // Include simple tools
#include "serial.h"                           // Half Duplex serial

#define LcdOn -1
#define LcdOff 0

/*
 *@brief Open a Connection to the LCD Display need before any call to other functions
 *
 *@parm Baud rate of LCD, Receive Pin not Used, Transmitt Pin.
 *
*/
void Lcd_Open(int Baud, int Rx, int Tx);

/*
 *@brief Position cursor on the LCD display.
 *
 *@parm Column from 0, Row from 0
 *
*/
void Lcd_PosCursor(int Col, int Row);

/*
 *@brief Play a note form A to G for a given length of time
 *
 *@parm Note to play 0 to 6, and length of note 64 - full
 *
*/
void Lcd_PlayNote(int Note, int Length);

/*
 *@brief Clear the LCD display and place the cursor at 0,0 with underline.
 *
 *@parm None.
 *
*/
void Lcd_Clr(void);

/*
 *@brief Change LCD display to turn display on/off, Cursor on/off, and Blink on/off
 *
 *@parm Display on/off, Cursor on/off, Blink on/off
 *
*/
void Lcd_Chg(int On, int Cursor, int Blink);

/*
 *@brief Turn LCD backlight on or off
 *
 *@parm Backlight on/off (LcdOn/LcdOFF).
 *
*/
void Lcd_BackLight(int On);

/*
 *@brief Send a set of characters to the LCD display
 *
 *@parm Character string to display on LCD null terminated
 *
*/
void Lcd_Chrs(char *characters);

/*
 *@brief Close Connection to the LCD Display.
 *
 *@parm None.
 *
*/
void Lcd_Close(void);

#endif